## USB to UART Bridge using MSP430 MCUs

### Example Summary

This [example code](add code link) implements an USB to UART bridge using a MSP430 microcontroller (MCU) to send data from one communication channel to the other.

This example code can use the GUI to connect to the two COM ports and display the sent data or separate terminal applications (ie; PuTTy, TerraTerm etc.) can be used to display the data.

The GUI example is available at [USB to UART Bridge](https://dev.ti.com/gallery/info/TIMSPGC/USB_to_UART_Bridge). The GUI example project is also included as a ZIP file and can be imported into [GUI Composer](https://dev.ti.com/gc/).

### Peripherals and Pin Assignments 


* P4.4/UCA1TXD --> TXD
* P4.5/UCA1RXD <-- RXD


All other pins are initialized as output low to reduce power consumption.

### Clock Configuration

* ACLK = REFO ~32768Hz (default)
* SMCLK = DCO + FLL + 32-KHz REFO reference = 24-MHz

### BoosterPacks, Board Resources and Jumper Settings

This example was developed and tested on the MSP-EXP430F5529 LaunchPad.


* Jumper GND: ON, Connects GND between the on-board debugger and LaunchPad 
* Jumper 3V3: ON, Powers the LaunchPad through USB
* Jumper RXD: ON, Enables back-channel UART communication
* Jumper TXD: ON, Enables back-channel UART communication

### Example Usage

* Connect the LaunchPad to your PC using the USB cable.

* Identify the COM port for the MSP Application UART interface and the USB Serial Interface 
	* found under "Ports" in Device 
Manager for Windows
	* USB Serial Interface only shows when code is running  


* If using the non-GUI (standalone) project:
	* Open 2 serial terminals (Docklight, Tera Term, PuTTy etc.) with the following settings:
		```
First Terminal-
		    COM Port:       COM# for MSP Application UART
		    Baud Rate:      9600
		    Data Bits:      8
		    Stop Bits:      1
		    Parity:         None
		    Flow Control:   None
Second Terminal-
		    COM Port:       COM# for USB Serial Device
		    Baud Rate:      9600
		    Data Bits:      8
		    Stop Bits:      1
		    Parity:         None
		    Flow Control:   None
		```
* If using the GUI project:
	* Import the GUI into [GUI Composer](https://dev.ti.com/gc/) and execute it.
	* Make sure the status at the bottom-left of the GUI shows "Hardware Connected".
	* Reset the device to initialize everything by pressing and releasing switch RST on the LaunchPad.
	* The device can be programmed by clicking file -> program device.
    * On the GUI terminals, click the refresh button (turning arrow) to have the GUI refresh and find open COM ports.
    * Select the correct COM port for the labeled terminal (COM ports can be found in your device manager)
    * Select the baud rate from the drop down menu (9600 for this demo)


* Then, continue with the example: 
	* How to send data to the USB terminal
		* On the UART terminal enter any character, it will then show up on the USB terminal.
    * How to send data to the UART terminal
		* On the USB terminal enter any character, it will then show up on the UART terminal.
			